pub fn contains_recursive_glob(component_selector: &ComponentSelector) -> boolExpand description
Returns true iff a component selector uses the recursive glob. Assumes the selector has already been validated.
pub fn contains_recursive_glob(component_selector: &ComponentSelector) -> boolReturns true iff a component selector uses the recursive glob. Assumes the selector has already been validated.