Module matching

Re-exports

pub use crate::context::*;

Structs

ElementSelectorFlags
Set of flags that are set on either the element or its parent (depending on the flag) if the element could potentially match a selector.

Enums

CompoundSelectorMatchingResult
Whether a compound selector matched, and whether it was the rightmost selector inside the complex selector.

Statics

RECOMMENDED_SELECTOR_BLOOM_FILTER_SIZE

Functions

matches_compound_selector_from
Matches a compound selector belonging to selector, starting at offset from_offset, matching left to right.
matches_selector
Matches a selector, fast-rejecting against a bloom filter.
matches_selector_kleene
Same as matches_selector, but returns the Kleene value as-is.
matches_selector_list
select_name
selector_may_match
Given the ancestor hashes from a selector, see if the current element, represented by the bloom filter, has a chance of matching at all.
to_unconditional_case_sensitivity