Re-exports
pub use crate::context::*;
Structs
- Element
Selector Flags - Set of flags that are set on either the element or its parent (depending on the flag) if the element could potentially match a selector.
Enums
- Compound
Selector Matching Result - Whether a compound selector matched, and whether it was the rightmost selector inside the complex selector.
Statics
Functions
- matches_
compound_ selector_ from - Matches a compound selector belonging to
selector, starting at offsetfrom_offset, matching left to right. - matches_
selector - Matches a selector, fast-rejecting against a bloom filter.
- matches_
selector_ kleene - Same as matches_selector, but returns the Kleene value as-is.
- matches_
selector_ list - select_
name - selector_
may_ match - Given the ancestor hashes from a selector, see if the current element, represented by the bloom filter, has a chance of matching at all.
- to_
unconditional_ case_ sensitivity